% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_analytics.R
\name{get_analytics}
\alias{get_analytics}
\title{Retrieves Disaggregated Analytics Data from DHIS2}
\usage{
get_analytics(
  ...,
  return_type = c("uid", "name"),
  retry = 2,
  verbosity = 0,
  timeout = 60
)
}
\arguments{
\item{...}{One or more \code{\link[=analytics_dimension]{analytics_dimension()}} parameters in key-value pairs.
These define the analytics query, including data elements, periods, and organization units.}

\item{return_type}{Optional argument specifying the return format for identifiers.
defaults to \code{'uid'}. Choose \code{'name'} for human readable labels.}

\item{retry}{Number of times to retry the API call in case of failure (defaults to 2).}

\item{verbosity}{Level of HTTP information to print during the call:
\itemize{
\item 0: No output
\item 1: Show headers
\item 2: Show headers and bodies
\item 3: Show headers, bodies, and CURL status message.
}}

\item{timeout}{Maximum number of seconds to wait for the API response.}
}
\value{
A tibble containing the disaggregated analytics data, or \code{NULL} if no data is retrieved.
}
\description{
\code{get_analytics()} retrieves disaggregated data from DHIS2 analytics tables for a
specified period and data element(s), without performing any aggregation.
}
\details{
\itemize{
\item Retrieves data directly from DHIS2 analytics tables.
\item Allows specifying analytics dimensions, return format for identifiers, retry
attempts, and logging verbosity.
}
}
\examples{
\dontshow{if (khis_has_cred()) (if (getRversion() >= "3.4") withAutoprint else force)(\{ # examplesIf}

# Clinical Breast Examination data elements
# XEX93uLsAm2 = CBE Abnormal
# cXe64Yk0QMY = CBE Normal
element_id <- c('cXe64Yk0QMY', 'XEX93uLsAm2')

# Download data from February 2023 to current date
data <- get_analytics(dx \%.d\% element_id, pe \%.d\% 'LAST_MONTH')
data
\dontshow{\}) # examplesIf}
}
